#' PKPDsim package
#'
#' Simulate regimens for PKPD models defined by ODE systems
#'
#' @name PKPDsim-package
#' @author Ron Keizer \email{ronkeizer@@gmail.com}
#' @importFrom utils packageVersion tail
#' @importFrom stats aggregate qnorm quantile reshape rnorm
#' @importFrom magrittr `%>%`
#' @keywords internal
"_PACKAGE"
